#version 330 compatibility

#define MAX_DISTANCE 12 // [1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32]
#define FALLOFF_CURVE 0.0 // [-10.0 -9.0 -8.0 -7.0 -6.0 -5.0 -4.0 -3.0 -2.0 -1.0 0.0 1.0 2.0 3.0 4.0 5.0 6.0 7.0 8.0 9.0 10.0]
uniform sampler2D depthtex0;

#define x intensity
#define a actualMaxDistance
#define p FALLOFF_CURVE

uniform float far;
uniform mat4 gbufferProjectionInverse;

in vec2 texcoord;

/* RENDERTARGETS: 0 */
layout(location = 0) out vec3 color;

float screenSpaceToViewSpace(float depth, mat4 projInv) {
	depth = depth * 2.0 - 1.0;
	return projInv[3].z / (projInv[2].w * depth + projInv[3].w);
}

void main() {
	float depth = texture(depthtex0, texcoord).r;
  depth = depth * 2.0 - 1.0;
  depth = screenSpaceToViewSpace(depth, gbufferProjectionInverse);

  const float actualMaxDistance = float(MAX_DISTANCE * 16.0);

  float intensity = max(-depth, 0.0);
  if(FALLOFF_CURVE != 0.0){
    intensity = (exp(p * (x / a)) - 1.0) / (exp(p) - 1.0);
  } else {
    intensity /= actualMaxDistance;
  }

  intensity = 1.0 - intensity;



  color = vec3(intensity);
}